@@ -3,9 +3,16 @@ from __future__ import annotations
 import os
 import re
 import sys
-from argparse import _ArgumentGroup  # noqa
-from argparse import _SubParsersAction  # noqa
-from argparse import SUPPRESS, Action, ArgumentParser, HelpFormatter
+from argparse import (
+    SUPPRESS,
+    Action,
+    ArgumentParser,
+    HelpFormatter,
+    _ArgumentGroup,
+    _StoreFalseAction,
+    _StoreTrueAction,
+    _SubParsersAction,
+)
 from collections import defaultdict, namedtuple
 from typing import Iterator, cast
 
@@ -23,8 +30,13 @@ from docutils.nodes import (
     section,
     strong,
     title,
+    whitespace_normalize_name,
+)
+from docutils.parsers.rst.directives import (  # type: ignore # no stubs
+    positive_int,
+    unchanged,
+    unchanged_required,
 )
-from docutils.parsers.rst.directives import positive_int, unchanged, unchanged_required
 from docutils.parsers.rst.states import RSTState, RSTStateMachine
 from docutils.statemachine import StringList
 from sphinx.domains.std import StandardDomain
@@ -36,7 +48,7 @@ TextAsDefault = namedtuple("TextAsDefault", ["text"])
 
 
 def make_id(key: str) -> str:
-    return "-".join(key.split()).rstrip("-").lower()
+    return "-".join(key.split()).rstrip("-")
 
 
 logger = getLogger(__name__)
@@ -85,17 +97,17 @@ class SphinxArgparseCli(SphinxDirective):
         return self._parser
 
     def load_sub_parsers(self) -> Iterator[tuple[list[str], str, ArgumentParser]]:
-        top_sub_parser = self.parser._subparsers  # noqa
+        top_sub_parser = self.parser._subparsers
         if not top_sub_parser:
             return
         parser_to_args: dict[int, list[str]] = defaultdict(list)
         str_to_parser: dict[str, ArgumentParser] = {}
-        sub_parser = cast(_SubParsersAction, top_sub_parser._group_actions[0])  # noqa
-        for key, parser in sub_parser._name_parser_map.items():  # noqa
+        sub_parser = cast(_SubParsersAction, top_sub_parser._group_actions[0])
+        for key, parser in sub_parser._name_parser_map.items():
             parser_to_args[id(parser)].append(key)
             str_to_parser[key] = parser
         done_parser: set[int] = set()
-        for name, parser in sub_parser.choices.items():  # noqa
+        for name, parser in sub_parser.choices.items():
             parser_id = id(parser)
             if parser_id in done_parser:
                 continue
@@ -120,8 +132,8 @@ class SphinxArgparseCli(SphinxDirective):
             home_section += desc_paragraph
         # construct groups excluding sub-parsers
         home_section += self._mk_usage(self.parser)
-        for group in self.parser._action_groups:  # noqa
-            if not group._group_actions or group is self.parser._subparsers:  # noqa
+        for group in self.parser._action_groups:
+            if not group._group_actions or group is self.parser._subparsers:
                 continue
             home_section += self._mk_option_group(group, prefix=self.parser.prog.split("/")[-1])
         # construct sub-parser
@@ -143,7 +155,7 @@ class SphinxArgparseCli(SphinxDirective):
             group_section += paragraph("", Text(group.description))
         self._register_ref(ref_id, title_text, group_section)
         opt_group = bullet_list()
-        for action in group._group_actions:  # noqa
+        for action in group._group_actions:
             point = self._mk_option_line(action, prefix)
             opt_group += point
         group_section += opt_group
@@ -172,7 +184,7 @@ class SphinxArgparseCli(SphinxDirective):
         title_text += group.title or ""
         return title_text
 
-    def _mk_option_line(self, action: Action, prefix: str) -> list_item:  # noqa
+    def _mk_option_line(self, action: Action, prefix: str) -> list_item:
         line = paragraph()
         as_key = action.dest
         if action.metavar:
@@ -200,7 +212,11 @@ class SphinxArgparseCli(SphinxDirective):
             line += Text(" - ")
             for content in cast(paragraph, temp.children[0]).children:
                 line += content
-        if action.default != SUPPRESS and not re.match(r".*[ (]default[s]? .*", (action.help or "")):
+        if (
+            action.default != SUPPRESS
+            and not re.match(r".*[ (]default[s]? .*", (action.help or ""))
+            and not isinstance(action, (_StoreTrueAction, _StoreFalseAction))
+        ):
             line += Text(" (default: ")
             line += literal(text=str(action.default).replace(os.getcwd(), "{cwd}"))
             line += Text(")")
@@ -214,15 +230,16 @@ class SphinxArgparseCli(SphinxDirective):
         st = strong()
         st += literal(text=opt)
         ref += st
-        self._register_ref(ref_id, ref_title, ref)
+        self._register_ref(ref_id, ref_title, ref, is_cli_option=True)
         line += ref
 
-    def _register_ref(self, ref_name: str, ref_title: str, node: Element) -> None:
+    def _register_ref(self, ref_name: str, ref_title: str, node: Element, is_cli_option: bool = False) -> None:
         doc_name = self.env.docname
+        normalize_name = whitespace_normalize_name if is_cli_option else fully_normalize_name
         if self.env.config.sphinx_argparse_cli_prefix_document:
-            name = fully_normalize_name(f"{doc_name}:{ref_name}")
+            name = normalize_name(f"{doc_name}:{ref_name}")
         else:
-            name = fully_normalize_name(ref_name)
+            name = normalize_name(ref_name)
         if name in self._std_domain.labels:
             logger.warning(
                 __("duplicate label %s, other instance in %s"),
@@ -255,7 +272,7 @@ class SphinxArgparseCli(SphinxDirective):
             desc_paragraph = paragraph("", Text(command_desc))
             group_section += desc_paragraph
         group_section += self._mk_usage(parser)
-        for group in parser._action_groups:  # noqa
+        for group in parser._action_groups:
             if not group._group_actions:  # do not show empty groups
                 continue
             group_section += self._mk_option_group(group, prefix=parser.prog)
